package nl.workshop.sqlite;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class DbAdapter {

	// DATABASE GLOBALS
	private static final String DATABASE_NAME = "workshop_database";
	private static final int DATABASE_VERSION = 4;
	private static final String DATABASE_TABLE = "names";
	
	// TABLE GLOBALS
	public static final String T_ROWID = "_id";
	public static final String T_NAME = "name";
	public static final String T_AGE = "age";
	public static final String T_ADDRESS = "address";
	public static final String T_PHONE = "phone";
	
	private static final String DATABASE_CREATE = "create table names (" +
			"_id integer primary key autoincrement, " +
			"name varchar(25), " +
			"age integer, " +
			"address varchar(25), " +
			"phone varchar(16));";
	
    private DatabaseHelper mDbHelper;
    private SQLiteDatabase mDb;

    private final Context context;

    private static class DatabaseHelper extends SQLiteOpenHelper {

        DatabaseHelper(Context context) {
            super(context, DATABASE_NAME, null, DATABASE_VERSION);
        }

        @Override
        public void onCreate(SQLiteDatabase db) {
            db.execSQL(DATABASE_CREATE);
        }

        @Override
        public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
            Log.w("DatabaseHelper", "Upgrading database from version " + oldVersion + " to "
                    + newVersion + ", which will destroy all old data");
            db.execSQL("DROP TABLE IF EXISTS names");
            onCreate(db);
        }
    }

    public DbAdapter(Context ctx) {
        this.context = ctx;
    }

    // DATABASE OPEN
    public DbAdapter open() throws SQLException {
        mDbHelper = new DatabaseHelper(context);
        mDb = mDbHelper.getWritableDatabase();
        return this;
    }
    
    // DATABASE CLOSE
    public void close() {
        mDbHelper.close();
    }
    
    // INSERT AN ITEM
    public long createNote(String name, String age, String address, String phone) {
        ContentValues initialValues = new ContentValues();
        initialValues.put(T_NAME, name);
        initialValues.put(T_AGE, age);
        initialValues.put(T_ADDRESS, address);
        initialValues.put(T_PHONE, phone);

        return mDb.insert(DATABASE_TABLE, null, initialValues);
    }
    
    // UPDATE ITEM
    public boolean updateItem(long rowId, String name, String age, String address, String phone) {
        ContentValues args = new ContentValues();
        args.put(T_NAME, name);
        args.put(T_AGE, age);
        args.put(T_ADDRESS, address);
        args.put(T_PHONE, phone);

        return mDb.update(DATABASE_TABLE, args, T_ROWID + "=" + rowId, null) > 0;
    }
    
    // DELETE AN ITEM
    public boolean deleteItem(long rowId) {
        return mDb.delete(DATABASE_TABLE, T_ROWID + "=" + rowId, null) > 0;
    }

    // SELECT ALL
    public Cursor fetchAllItems() {
        return mDb.query(DATABASE_TABLE, new String[] {T_ROWID, T_NAME, T_AGE, T_ADDRESS, T_PHONE}, null, null, null, null, null);
    }
    
    // SELECT ONE ITEM
    public Cursor fetchNote(long rowId) throws SQLException {

        Cursor mCursor =
        	mDb.query(true, DATABASE_TABLE, new String[] {T_ROWID, T_NAME, T_AGE, T_ADDRESS, T_PHONE}, T_ROWID + "=" + rowId, null, null, null, null, null);
        if (mCursor != null) {
            mCursor.moveToFirst();
        }
        return mCursor;

    }
   
}
