package nl.workshop.sqlite;

import android.app.Activity;
import android.database.Cursor;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

public class EditItem extends Activity{

	private EditText mNameText;
    private EditText mAgeText;
    private EditText mAddressText;
    private EditText mPhoneText;
    
    private Long mRowId;
    private DbAdapter mDbHelper;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        mDbHelper = new DbAdapter(this);
        mDbHelper.open();
        
        // SET TEMPLATE
        setContentView(R.layout.edit_item);
        
        // (EditText) fields
        mNameText = (EditText) findViewById(R.id.name);
        mAgeText = (EditText) findViewById(R.id.age);
        mAddressText = (EditText) findViewById(R.id.address);
        mPhoneText = (EditText) findViewById(R.id.phone);
      
        // (Button) button
        Button confirmButton = (Button) findViewById(R.id.confirm);
       
        // check if new item or updating item
        mRowId = savedInstanceState != null ? savedInstanceState.getLong(DbAdapter.T_ROWID) 
                							: null;
		if (mRowId == null) {
			Bundle extras = getIntent().getExtras();            
			mRowId = extras != null ? extras.getLong(DbAdapter.T_ROWID) 
									: null;
		}

		// If updating: set all fields with their values
		populateFields();
		
        confirmButton.setOnClickListener(new View.OnClickListener() {

        	public void onClick(View view) {
        	    setResult(RESULT_OK);
        	    finish();
        	}
        });
    }
    
    // SET FieldValues
    private void populateFields() {
        if (mRowId != null) {
            Cursor a = mDbHelper.fetchNote(mRowId);
            startManagingCursor(a);
            mNameText.setText(a.getString(a.getColumnIndexOrThrow(DbAdapter.T_NAME)));
            mAgeText.setText(a.getString(a.getColumnIndexOrThrow(DbAdapter.T_AGE)));
            mAddressText.setText(a.getString(a.getColumnIndexOrThrow(DbAdapter.T_ADDRESS)));
            mPhoneText.setText(a.getString(a.getColumnIndexOrThrow(DbAdapter.T_PHONE)));
        }
    }
    
    @Override
    protected void onSaveInstanceState(Bundle outState) {
        super.onSaveInstanceState(outState);
        outState.putLong(DbAdapter.T_ROWID, mRowId);
    }
    
    @Override
    protected void onPause() {
        super.onPause();
        saveState();
    }
    
    @Override
    protected void onResume() {
        super.onResume();
        populateFields();
    }
    
    // SAVE ALL new values
    private void saveState() {
        String name = mNameText.getText().toString();
        String age = mAgeText.getText().toString();
        String address = mAddressText.getText().toString();
        String phone = mPhoneText.getText().toString();

        if (mRowId == null) {
            long id = mDbHelper.createNote(name, age, address, phone);
            if (id > 0) {
                mRowId = id;
            }
        } else {
            mDbHelper.updateItem(mRowId, name, age, address, phone);
        }
    }
}
